#
# Conditional build:
%bcond_without	apidocs		# do not build and package API docs
%bcond_without	sane		# SANE support
%bcond_without	static_libs	# don't build static libraries
%bcond_without	vala		# don't build Vala API

Summary:	Color daemon - system daemon for managing color devices
Summary(pl.UTF-8):	Demon colord - usługa systemowa do zarządzania urządzeniami obsługującymi kolory
Name:		colord
# note: 1.3.x is devel; stick to stable line when possible (some GNOME 3.20 components require colord >= 1.3.1)
Version:	1.3.4
Release:	1
License:	GPL v2+ and LGPL v2+
Group:		Daemons
Source0:	https://www.freedesktop.org/software/colord/releases/%{name}-%{version}.tar.xz
# Source0-md5:	5e889426907a0436ecfbdb18add2c67b
Patch0:		%{name}-completions.patch
Patch1:		%{name}-sh.patch
URL:		https://www.freedesktop.org/software/colord/
BuildRequires:	autoconf >= 2.63
BuildRequires:	automake >= 1:1.9
BuildRequires:	dbus-devel
BuildRequires:	docbook-utils
BuildRequires:	gettext-tools >= 0.17
BuildRequires:	glib2-devel >= 1:2.44.0
BuildRequires:	gobject-introspection-devel >= 0.9.8
BuildRequires:	gtk-doc >= 1.9
BuildRequires:	intltool >= 0.40.0
BuildRequires:	lcms2-devel >= 2.6
BuildRequires:	libgusb-devel >= 0.2.7
BuildRequires:	libtool >= 2:2.0
BuildRequires:	pkgconfig
BuildRequires:	polkit-devel >= 0.103
BuildRequires:	rpmbuild(macros) >= 1.644
%{?with_sane:BuildRequires:	sane-backends-devel}
BuildRequires:	sqlite3-devel >= 3
BuildRequires:	systemd-devel >= 44
BuildRequires:	udev-devel
BuildRequires:	udev-glib-devel
%{?with_vala:BuildRequires:	vala}
Requires(post,preun,postun):	systemd-units >= 44
Requires:	%{name}-libs = %{version}-%{release}
Requires:	polkit >= 0.103
Requires:	systemd-units >= 44
# /usr/bin/spotread called by argyll sensor driver
Suggests:	argyllcms
Suggests:	shared-color-profiles
Provides:	group(colord)
Provides:	user(colord)
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
colord is a low level system activated daemon that maps color devices
to color profiles in the system context.

%description -l pl.UTF-8
colord to niskopoziomowa usługa systemowa odwzorowująca urządzenia
obsługujące kolory na profile kolorów w kontekście systemu.

%package libs
Summary:	colord library
Summary(pl.UTF-8):	Biblioteka colord
Group:		Libraries
Requires:	glib2 >= 1:2.44.0
Requires:	lcms2 >= 2.6
# for libcolorhug only
Requires:	libgusb >= 0.2.7
Suggests:	%{name} = %{version}-%{release}
Obsoletes:	colorhug-client-libs < 0.1.14
Conflicts:	colord < 0.1.12-4

%description libs
colord library.

%description libs -l pl.UTF-8
Biblioteka colord.

%package devel
Summary:	Header files for colord library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki colord
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	dbus-devel
Requires:	glib2-devel >= 1:2.44.0
Requires:	lcms2-devel >= 2.6
Requires:	libgusb-devel >= 0.2.7
Obsoletes:	colorhug-client-devel < 0.1.14

%description devel
Header files for colord library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki colord.

%package static
Summary:	Static colord library
Summary(pl.UTF-8):	Statyczna biblioteka colord
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Obsoletes:	colorhug-client-static < 0.1.14

%description static
Static colord library.

%description static -l pl.UTF-8
Statyczna biblioteka colord.

%package apidocs
Summary:	colord API documentation
Summary(pl.UTF-8):	Dokumentacja API colord
Group:		Documentation
Requires:	gtk-doc-common
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
colord API documentation.

%description apidocs -l pl.UTF-8
Dokumentacja API colord.

%package -n vala-colord
Summary:	colord API for Vala language
Summary(pl.UTF-8):	API colord dla języka Vala
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description -n vala-colord
colord API for Vala language.

%description -n vala-colord -l pl.UTF-8
API colord dla języka Vala.

%package -n bash-completion-colord
Summary:	bash-completion for colormgr console commands
Summary(pl.UTF-8):	Bashowe uzupełnianie poleceń terminalowych colormgr
Group:		Applications/Shells
Requires:	bash-completion >= 2.0
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description -n bash-completion-colord
bash-completion for colormgr console commands.

%description -n bash-completion-colord -l pl.UTF-8
Bashowe uzupełnianie poleceń terminalowych colormgr.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
%{__intltoolize}
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	SPOTREAD=/usr/bin/spotread \
	--disable-silent-rules \
	--enable-bash-completion=%{bash_compdir} \
	%{__enable_disable apidocs gtk-doc} \
	--enable-libcolordcompat \
	%{__enable sane} \
	%{__enable_disable static_libs static} \
	%{__enable_disable vala} \
	--with-daemon-user=colord \
	--with-html-dir=%{_gtkdocdir} \
	--with-systemdsystemunitdir=%{systemdunitdir}
# doc build is broken with -j
%{__make} -j1

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/*.la
# loadable modules
%{__rm} $RPM_BUILD_ROOT%{_libdir}/colord-{plugins,sensors}/*.{la,a}

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%pre
%groupadd -g 331 colord
%useradd -u 331 -d /var/lib/colord -g colord -c "colord daemon user" colord

%post
%glib_compile_schemas

%postun
%systemd_reload
if [ "$1" = "0" ]; then
	%glib_compile_schemas
	%userremove colord
	%groupremove colord
fi

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog NEWS README.md TODO
%attr(755,root,root) %{_bindir}/cd-create-profile
%attr(755,root,root) %{_bindir}/cd-fix-profile
%attr(755,root,root) %{_bindir}/cd-iccdump
%attr(755,root,root) %{_bindir}/cd-it8
%attr(755,root,root) %{_bindir}/colormgr
%attr(755,root,root) %{_libexecdir}/colord
%{?with_sane:%attr(755,root,root) %{_libexecdir}/colord-sane}
%attr(755,root,root) %{_libexecdir}/colord-session
%dir %{_libdir}/colord-plugins
%attr(755,root,root) %{_libdir}/colord-plugins/libcd_plugin_camera.so
%{?with_sane:%attr(755,root,root) %{_libdir}/colord-plugins/libcd_plugin_sane.so}
%attr(755,root,root) %{_libdir}/colord-plugins/libcd_plugin_scanner.so
%dir %{_libdir}/colord-sensors
%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_argyll.so
%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_colorhug.so
%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_dtp94.so
%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_dummy.so
%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_huey.so
# disabled for now
#%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_munki.so
%attr(755,root,root) %{_libdir}/colord-sensors/libcolord_sensor_spark.so
%attr(755,root,root) %{_libdir}/colord-sensors/libdtp94-private.so
%attr(755,root,root) %{_libdir}/colord-sensors/libhuey-private.so
%attr(755,root,root) %{_libdir}/colord-sensors/libmunki-private.so
%attr(755,root,root) %{_libdir}/colord-sensors/libospark-private.so
%{_datadir}/colord
%{_datadir}/color/icc/colord
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorHelper.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager.Device.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager.Profile.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager.Sensor.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.ColorManager.xml
%{_datadir}/dbus-1/services/org.freedesktop.ColorHelper.service
%{_datadir}/dbus-1/system-services/org.freedesktop.ColorManager.service
%{_datadir}/glib-2.0/schemas/org.freedesktop.ColorHelper.gschema.xml
%{_datadir}/polkit-1/actions/org.freedesktop.color.policy
%{_mandir}/man1/cd-create-profile.1*
%{_mandir}/man1/cd-fix-profile.1*
%{_mandir}/man1/cd-it8.1*
%{_mandir}/man1/colormgr.1*
%{systemdunitdir}/colord.service
%{systemduserunitdir}/colord-session.service
%{systemdtmpfilesdir}/colord.conf
/etc/dbus-1/system.d/org.freedesktop.ColorManager.conf
/lib/udev/rules.d/69-cd-sensors.rules
/lib/udev/rules.d/95-cd-devices.rules
%attr(755,colord,colord) %dir /var/lib/colord
%attr(755,colord,colord) %dir /var/lib/colord/icc

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libcolord.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libcolord.so.2
%attr(755,root,root) %{_libdir}/libcolordcompat.so
%attr(755,root,root) %{_libdir}/libcolordprivate.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libcolordprivate.so.2
%attr(755,root,root) %{_libdir}/libcolorhug.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libcolorhug.so.2
%{_libdir}/girepository-1.0/Colord-1.0.typelib
%{_libdir}/girepository-1.0/ColorHug-1.0.typelib

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libcolord.so
%attr(755,root,root) %{_libdir}/libcolordprivate.so
%attr(755,root,root) %{_libdir}/libcolorhug.so
%{_includedir}/colord-1
%{_pkgconfigdir}/colord.pc
%{_pkgconfigdir}/colorhug.pc
%{_datadir}/gir-1.0/Colord-1.0.gir
%{_datadir}/gir-1.0/ColorHug-1.0.gir

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libcolord.a
%{_libdir}/libcolordcompat.a
%{_libdir}/libcolordprivate.a
%{_libdir}/libcolorhug.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/colord
%endif

%if %{with vala}
%files -n vala-colord
%defattr(644,root,root,755)
%{_datadir}/vala/vapi/colord.vapi
%endif

%files -n bash-completion-colord
%defattr(644,root,root,755)
%{bash_compdir}/colormgr
%changelog
* Wed Dec 28 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/colord.git;a=log;h=master

* Tue Dec 27 2016 Jakub Bogusz <qboosh@pld-linux.org> d1e278b
- updated to 1.3.4

* Thu Sep 08 2016 Jakub Bogusz <qboosh@pld-linux.org> e4ce8df
- updated to 1.3.3 (devel line, but required by stable gnome-color-manager 3.20)
- use separate daemon user (colord:colord) instead of root

* Mon Mar 28 2016 Elan Ruusamäe <glen@delfi.ee> 6df1e0a
- noarch vala subpackage

* Tue Dec 08 2015 Elan Ruusamäe <glen@delfi.ee> 6ea2203
- noarch apidocs

* Sun Sep 06 2015 Jakub Bogusz <qboosh@pld-linux.org> 8b71f28
- updated to 1.2.12

* Sun Jun 14 2015 Jakub Bogusz <qboosh@pld-linux.org> 0322742
- updated to 1.2.11

* Sat Apr 11 2015 Jakub Bogusz <qboosh@pld-linux.org> abf9232
- updated to 1.2.10

* Sun Mar 01 2015 Elan Ruusamäe <glen@delfi.ee> 674ec37
- x32 rebuild
- release 2 (by relup.sh)

* Tue Feb 24 2015 Jakub Bogusz <qboosh@pld-linux.org> f8a0473
- Merge branch 'master' of git://git.pld-linux.org/packages/colord

* Tue Feb 24 2015 Jakub Bogusz <qboosh@pld-linux.org> a78424e
- updated to 1.2.9

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> ab77123
- x32 rebuild
- release 3 (by relup.sh)

* Sat Jan 17 2015 Jakub Bogusz <qboosh@pld-linux.org> 110eb9e
- release 2

* Sat Jan 17 2015 Jakub Bogusz <qboosh@pld-linux.org> ad44270
- base R: polkit, not just libs

* Sat Jan 17 2015 Jakub Bogusz <qboosh@pld-linux.org> e5ac2fe
- fix it_IT again

* Sat Jan 17 2015 Jakub Bogusz <qboosh@pld-linux.org> 62904fa
- updated to 1.2.8

* Sun Dec 28 2014 Jan Rękorajski <baggins@pld-linux.org> 1e22f0f
- updated gettext BR

* Fri Dec 05 2014 Jakub Bogusz <qboosh@pld-linux.org> 345d835
- updated to 1.2.7

* Sun Nov 16 2014 Jakub Bogusz <qboosh@pld-linux.org> b410bad
- updated to 1.2.5

* Sat Nov 01 2014 Jakub Bogusz <qboosh@pld-linux.org> 9d6dcfe
- updated to 1.2.4

* Thu Sep 18 2014 Jakub Bogusz <qboosh@pld-linux.org> 48515d7
- updated to 1.2.3

